<template>
  <div class="edit-add-detail detail show-scrollbar">
    <div
      v-loading="detailLoading"
      class="form-content"
      element-loading-background="rgba(10 ,38 ,61, 0.9)"
      element-loading-text="详情加载中..."
    >
      <el-form
        ref="formInfo"
        :model="detailForm"
        class="detail-form"
        label-position="right"
        label-suffix="："
      >
        <div class="rows">
          <div class="rows-left">
            <div class="rows-hr"></div>
          </div>
          <div class="rows-title">
            <div class="text-overflow">沿线设施基础数据</div>
          </div>
        </div>
        <el-row :gutter="24" style="flex-wrap: wrap" type="flex">
          <el-col :span="6">
            <el-form-item label="沿线设施编号">
                <span :title="detailForm.number" class="text">
                  {{ detailForm.number || '-' }}
                </span>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="沿线设施名称">
                <span :title="detailForm.name" class="text">
                  {{ detailForm.name || '-' }}
                </span>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="所属路段">
                <span :title="detailForm.roadSegmentName" class="text">
                  {{ detailForm.roadSegmentName || '-' }}
                </span>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="类型">
                <span :title="dictionaryEscape('yxss',detailForm.type)" class="text">
                  {{ dictionaryEscape('yxss', detailForm.type) || '-' }}
                </span>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="方向">
                <span :title="dictionaryEscape('qlfx',detailForm.direction)" class="text">
                  {{ dictionaryEscape('qlfx', detailForm.direction) || '-' }}
                </span>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="桩号值(KM)">
                <span :title="detailForm.pegK" class="text">
                  {{ detailForm.pegK || '-' }}
                </span>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="桩号(数字)">
                <span :title="detailForm.peg" class="text">
                  {{ detailForm.peg || '-' }}
                </span>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="管养单位">
                <span :title="detailForm.officeName" class="text">
                  {{ detailForm.officeName || '-' }}
                </span>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="经度">
                <span :title="detailForm.lng" class="text">
                  {{ detailForm.lng || '-' }}
                </span>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="纬度">
                <span :title="detailForm.lat" class="text">
                  {{ detailForm.lat || '-' }}
                </span>
            </el-form-item>
          </el-col>
          <el-col :span="24">
            <el-form-item label="详细说明">
                <span :title="detailForm.expound" class="show-all">
                  {{ detailForm.expound || '-' }}
                </span>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
    </div>

    <el-backtop :visibility-height="20" target=".detail-form">
      <div class="top-box">UP</div>
    </el-backtop>
  </div>
</template>

<script>
import {tableDetail} from '@/api/patrolAndRescue/infoMgmtPatrolsRescues/alongRouteInfo'
import PubSub from 'pubsub-js'
import {dictionaryEscape} from '@/utils/dictionary'

export default {
  name: 'DetailPage',
  props: {
    componentName: {
      default: 'TablePage',
      type: String
    }
  },
  components: {},
  data() {
    return {
      detailForm: {},
      detailLoading: true,
      pubSub: null
    }
  },
  watch: {
    componentName: {
      handler(newVal) {
        if (newVal === this.$options.name) {
          this.openPage()
        } else {
          this.closePage()
        }
      }
    }
  },
  mounted() {
    this.pubSub = PubSub.subscribe('DetailPage', (_, data) => {
      if (data.id) {
        this.getDetail(data.id)
      }
    })
  },
  methods: {
    dictionaryEscape,

    // 打开页面执行
    openPage() {
    },

    // 关闭页面执行
    closePage() {
      // 重置组件数据
      Object.assign(this.$data, this.$options.data.call(this), {pubSub: this.pubSub})
      this.$nextTick(_ => {
        this.$refs.formInfo.$el.scrollTop = 0
      })
    },

    // 获取详情
    async getDetail(id) {
      try {
        const {...detailForm} = await tableDetail(id)
        this.detailForm = detailForm
      } finally {
        this.detailLoading = false
      }
    }
  },
  beforeDestroy() {
    // 在组件销毁之前 清除订阅消息
    PubSub.unsubscribe(this.pubSub)
  }
}
</script>

<style lang="scss" scoped>
</style>
